@@ -101,7 +101,7 @@ def play_function(difficulty: List, font: 'pygame.font.Font', test: bool = False
                 if e.key == pygame.K_ESCAPE:
                     main_menu.enable()
 
-                    # Quit this function, then skip to loop of main-menu on line 223
+                    # Quit this function, then skip to loop of main-menu on line 221
                     return
 
         # Pass events to main_menu
@@ -110,10 +110,8 @@ def play_function(difficulty: List, font: 'pygame.font.Font', test: bool = False
 
         # Continue playing
         surface.fill(bg_color)
-        surface.blit(f, (int((WINDOW_SIZE[0] - f.get_width()) / 2),
-                         int(WINDOW_SIZE[1] / 2 - f.get_height())))
-        surface.blit(f_esc, (int((WINDOW_SIZE[0] - f_esc.get_width()) / 2),
-                             int(WINDOW_SIZE[1] / 2 + f_esc.get_height())))
+        surface.blit(f, (int((WINDOW_SIZE[0] - f.get_width()) / 2), int(WINDOW_SIZE[1] / 2 - f.get_height())))
+        surface.blit(f_esc, (int((WINDOW_SIZE[0] - f_esc.get_width()) / 2), int(WINDOW_SIZE[1] / 2 + f_esc.get_height())))
         pygame.display.flip()
 
         # If test returns
