@@ -136,60 +136,60 @@ class DropSelectMultiple(DropSelect):
     _selection_placeholder_format: DropSelectMultipleSFormatType
 
     def __init__(
-            self,
-            title: Any,
-            items: Union[List[Tuple[Any, ...]], List[str]],
-            dropselect_id: str = '',
-            default: Optional[Union[int, List[int]]] = None,
-            max_selected: int = 0,
-            onchange: CallbackType = None,
-            onreturn: CallbackType = None,
-            onselect: CallbackType = None,
-            open_middle: bool = False,
-            placeholder: str = 'Select an option',
-            placeholder_add_to_selection_box: bool = True,
-            placeholder_selected: str = '{0} selected',
-            scrollbar_color: ColorInputType = (235, 235, 235),
-            scrollbar_cursor: CursorInputType = None,
-            scrollbar_shadow: bool = False,
-            scrollbar_shadow_color: ColorInputType = (0, 0, 0),
-            scrollbar_shadow_offset: int = 2,
-            scrollbar_shadow_position: str = POSITION_NORTHWEST,
-            scrollbar_slider_color: ColorInputType = (200, 200, 200),
-            scrollbar_slider_hover_color: ColorInputType = (170, 170, 170),
-            scrollbar_slider_pad: NumberType = 0,
-            scrollbar_thick: int = 20,
-            scrollbars: str = POSITION_SOUTHEAST,
-            selection_box_arrow_color: ColorInputType = (150, 150, 150),
-            selection_box_arrow_margin: Tuple3IntType = (5, 5, 0),
-            selection_box_bgcolor: ColorInputType = (255, 255, 255),
-            selection_box_border_color: ColorInputType = (150, 150, 150),
-            selection_box_border_width: int = 1,
-            selection_box_height: int = 3,
-            selection_box_inflate: Tuple2IntType = (0, 0),
-            selection_box_margin: Tuple2NumberType = (25, 0),
-            selection_box_text_margin: int = 5,
-            selection_box_width: int = 0,
-            selection_infinite: bool = False,
-            selection_option_active_bgcolor: ColorInputType = (188, 227, 244),
-            selection_option_active_font_color: ColorInputType = (0, 0, 0),
-            selection_option_border_color: ColorInputType = (220, 220, 220),
-            selection_option_border_width: int = 1,
-            selection_option_cursor: CursorInputType = None,
-            selection_option_font: Optional[FontType] = None,
-            selection_option_font_color: ColorInputType = (0, 0, 0),
-            selection_option_font_size: Optional[int] = None,
-            selection_option_padding: PaddingType = 5,
-            selection_option_selected_bgcolor: ColorInputType = (142, 247, 141),
-            selection_option_selected_box: bool = True,
-            selection_option_selected_box_border: int = 1,
-            selection_option_selected_box_color: ColorInputType = (150, 150, 150),
-            selection_option_selected_box_height: float = 0.5,
-            selection_option_selected_box_margin: Tuple3IntType = (0, 5, 0),
-            selection_option_selected_font_color: ColorInputType = (0, 0, 0),
-            selection_placeholder_format: DropSelectMultipleSFormatType = DROPSELECT_MULTIPLE_SFORMAT_TOTAL,
-            *args,
-            **kwargs
+        self,
+        title: Any,
+        items: Union[List[Tuple[Any, ...]], List[str]],
+        dropselect_id: str = '',
+        default: Optional[Union[int, List[int]]] = None,
+        max_selected: int = 0,
+        onchange: CallbackType = None,
+        onreturn: CallbackType = None,
+        onselect: CallbackType = None,
+        open_middle: bool = False,
+        placeholder: str = 'Select an option',
+        placeholder_add_to_selection_box: bool = True,
+        placeholder_selected: str = '{0} selected',
+        scrollbar_color: ColorInputType = (235, 235, 235),
+        scrollbar_cursor: CursorInputType = None,
+        scrollbar_shadow: bool = False,
+        scrollbar_shadow_color: ColorInputType = (0, 0, 0),
+        scrollbar_shadow_offset: int = 2,
+        scrollbar_shadow_position: str = POSITION_NORTHWEST,
+        scrollbar_slider_color: ColorInputType = (200, 200, 200),
+        scrollbar_slider_hover_color: ColorInputType = (170, 170, 170),
+        scrollbar_slider_pad: NumberType = 0,
+        scrollbar_thick: int = 20,
+        scrollbars: str = POSITION_SOUTHEAST,
+        selection_box_arrow_color: ColorInputType = (150, 150, 150),
+        selection_box_arrow_margin: Tuple3IntType = (5, 5, 0),
+        selection_box_bgcolor: ColorInputType = (255, 255, 255),
+        selection_box_border_color: ColorInputType = (150, 150, 150),
+        selection_box_border_width: int = 1,
+        selection_box_height: int = 3,
+        selection_box_inflate: Tuple2IntType = (0, 0),
+        selection_box_margin: Tuple2NumberType = (25, 0),
+        selection_box_text_margin: int = 5,
+        selection_box_width: int = 0,
+        selection_infinite: bool = False,
+        selection_option_active_bgcolor: ColorInputType = (188, 227, 244),
+        selection_option_active_font_color: ColorInputType = (0, 0, 0),
+        selection_option_border_color: ColorInputType = (220, 220, 220),
+        selection_option_border_width: int = 1,
+        selection_option_cursor: CursorInputType = None,
+        selection_option_font: Optional[FontType] = None,
+        selection_option_font_color: ColorInputType = (0, 0, 0),
+        selection_option_font_size: Optional[int] = None,
+        selection_option_padding: PaddingType = 5,
+        selection_option_selected_bgcolor: ColorInputType = (142, 247, 141),
+        selection_option_selected_box: bool = True,
+        selection_option_selected_box_border: int = 1,
+        selection_option_selected_box_color: ColorInputType = (150, 150, 150),
+        selection_option_selected_box_height: float = 0.5,
+        selection_option_selected_box_margin: Tuple3IntType = (0, 5, 0),
+        selection_option_selected_font_color: ColorInputType = (0, 0, 0),
+        selection_placeholder_format: DropSelectMultipleSFormatType = DROPSELECT_MULTIPLE_SFORMAT_TOTAL,
+        *args,
+        **kwargs
     ) -> None:
         super(DropSelectMultiple, self).__init__(
             dropselect_id=dropselect_id,
@@ -275,9 +275,11 @@ class DropSelectMultiple(DropSelect):
 
     def _render_option_string(self, text: str) -> 'pygame.Surface':
         color = self._selection_option_font_style['color']
-        if self.readonly or \
-                len(self._selected_indices) == 0 or \
-                self._max_selected != 0 and len(self._selected_indices) == self._max_selected:
+        if (
+            self.readonly or
+            len(self._selected_indices) == 0 or
+            self._max_selected != 0 and len(self._selected_indices) == self._max_selected
+        ):
             color = self._font_readonly_color
         text = text.replace('\t', ' ' * self._tab_size)
         return self._option_font.render(text, self._font_antialias, color)
@@ -536,21 +538,21 @@ class DropSelectMultipleManager(AbstractWidgetManager, ABC):
     """
 
     def dropselect_multiple(
-            self,
-            title: Any,
-            items: Union[List[Tuple[Any, ...]], List[str]],
-            default: Optional[Union[int, List[int]]] = None,
-            dropselect_multiple_id: str = '',
-            max_selected: int = 0,
-            onchange: CallbackType = None,
-            onreturn: CallbackType = None,
-            onselect: Optional[Callable[[bool, 'Widget', 'pygame_menu.Menu'], Any]] = None,
-            open_middle: bool = False,
-            placeholder: str = 'Select an option',
-            placeholder_add_to_selection_box: bool = True,
-            placeholder_selected: str = '{0} selected',
-            selection_placeholder_format: DropSelectMultipleSFormatType = DROPSELECT_MULTIPLE_SFORMAT_TOTAL,
-            **kwargs
+        self,
+        title: Any,
+        items: Union[List[Tuple[Any, ...]], List[str]],
+        default: Optional[Union[int, List[int]]] = None,
+        dropselect_multiple_id: str = '',
+        max_selected: int = 0,
+        onchange: CallbackType = None,
+        onreturn: CallbackType = None,
+        onselect: Optional[Callable[[bool, 'Widget', 'pygame_menu.Menu'], Any]] = None,
+        open_middle: bool = False,
+        placeholder: str = 'Select an option',
+        placeholder_add_to_selection_box: bool = True,
+        placeholder_selected: str = '{0} selected',
+        selection_placeholder_format: DropSelectMultipleSFormatType = DROPSELECT_MULTIPLE_SFORMAT_TOTAL,
+        **kwargs
     ) -> 'pygame_menu.widgets.DropSelectMultiple':
         """
         Add a dropselect multiple to the Menu: Drop select multiple is a drop
